@@ -2,6 +2,7 @@
 # autogen.sh script for nettoe 
 # Edited by Gabriele Giorgetti <g.gabriele@europe.com>
 #
+# For nettoe-1.2.0: use '--ignore-deps' with automake.
 
 DIE=0
 
@@ -41,8 +42,8 @@ fi
 aclocal 						\
 && echo "Running autoheader..."				\
 && autoheader						\
-&& echo "Running automake --gnu --add-missing ..."	\
-&& automake --gnu --add-missing				\
+&& echo "Running automake --gnu --add-missing --ignore-deps ..."	\
+&& automake --gnu --add-missing --ignore-deps		\
 && echo "Running autoconf ..."				\
 && autoconf
 
