@@ -1,6 +1,7 @@
-/* netToe Version 1.2.1
- * Release date: 3 January 2010
+/* netToe Version 1.3.2
+ * Release date: 18 March 2010
  * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
+ *           2009,2010 Mats Erik Andersson <meand@users.sourceforge.net>
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,18 +22,15 @@
 #define HOMEPAGE     "http://nettoe.sourceforge.net"
 #define AUTHOR_EMAIL "<ggdev@users.sourceforge.net>"
 #define AUTHOR2_EMAIL "<meand@users.sourceforge.net>"
-#define RELEASE_DATE "3 January 2010"
+#define RELEASE_DATE "18 March 2010"
 
 #define SERVER_PORT_NUMBER 7501
-#define CLIENT_PORT_NUMBER 7502
+
 #define MAXDATASIZE 50
 
-#define MAX_PNAME_LEN 15 /* this define max chars for the player names*/
+#define MAX_PNAME_LEN 32 /* this define max chars for the player names*/
 
 int NO_BEEP;
 
 int NO_COLORS;
 
-
-
-
