@@ -1,5 +1,5 @@
-/* netToe Version 1.2.0
- * Release date: 30 December 2009
+/* netToe Version 1.3.0
+ * Release date: 24 February 2010
  * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
  *		
  *
@@ -18,23 +18,19 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <time.h>
 
+void beep(void);
 
-void beep ( void );
+void parse_cmd_args(int argc, char *argv[]);
 
-void parse_cmd_args (int argc, char *argv[]);
+void get_player_pname(char * str, int maxlen);
 int check_pname(const char *pname, int maxlen);
-int who_start_first (void);
-void print_infos_screen (void);
-
-
-
-
 
+int who_start_first(void);
+void print_infos_screen(void);
 
