@@ -1,5 +1,5 @@
-/* netToe Version 1.2.0
- * Release date: 30 December 2009
+/* netToe Version 1.3.0
+ * Release date: 24 February 2010
  * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
  *		
  *
@@ -18,6 +18,9 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#ifndef	_NETWORK_H
+#define _NETWORK_H 1
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -35,14 +38,13 @@
 #include <netdb.h>
 
                      
-extern int establish_listening_socket ( unsigned short port_number, char peer_ip_address[20]);
-extern int connect_to_socket ( char host_ip_number[20], unsigned short port_number );
+extern int establish_listening_socket ( unsigned short port_number, char peer_ip_address[INET6_ADDRSTRLEN]);
+extern int connect_to_socket ( char host_ip_number[INET6_ADDRSTRLEN], unsigned short port_number );
 extern int write_to_socket ( int connected_socket, char *buffer, int bytes );
 extern int read_from_socket (int connected_socket, char *buffer, int bytes);
 
-extern const char *give_local_IP ( void );
+extern void give_local_IP ( char * local_ip_address );
 
 /* extern const char *give_local_hostname ( void ); */ /* NOT USED */
 
-
-
+#endif	/* _NETWORK_H */
